==> crm-commom-1.2.2.11.release.jar: com/biz/crm/util/ParamUtil.java <==
package com.biz.crm.util;

import com.biz.crm.common.param.RedisParam;
import com.biz.crm.parameter.feign.ParameterFeign;
import com.biz.crm.parameter.vo.ParameterVo;
import com.biz.crm.service.RedisService;
import lombok.extern.slf4j.Slf4j;

import java.util.*;
import java.util.stream.Collectors;


/**
 * 全局参数工具类
 *
 * @author Tao.Chen
 * @date 2020-11-28 20:04:56
 */
@Slf4j
public class ParamUtil {

    private static ParameterFeign parameterFeign;
    private static RedisService redisService;

    public static void setParameterFeign(ParameterFeign feign) {
        parameterFeign = feign;
    }

    public static void setRedisService(RedisService redis) {
        redisService = redis;
    }

    /**
     * 根据参数编码获取当前值
     *
     * @param parameterCode
     * @return
     */
    public static String getParameterValue(String parameterCode) {
        if (parameterCode != null && !"".equals(parameterCode)) {
            ParameterVo parameterVo = getParameterVo(parameterCode);
            if (parameterVo != null) {
                return parameterVo.getParameterValue();
            }
        }
        return null;
    }

    /**
     * 根据参数编码集合获取当前值Map
     *
     * @param parameterCodeList
     * @return
     */
    public static Map<String, String> getParameterValueMap(List<String> parameterCodeList) {
        Map<String, String> map = new HashMap<>(16);
        if (parameterCodeList != null && parameterCodeList.size() > 0) {
            Map<String, ParameterVo> parameterVoMap = basicMap(parameterCodeList);
            if (!parameterVoMap.isEmpty()) {
                for (Map.Entry<String, ParameterVo> entry :
                        parameterVoMap.entrySet()) {
                    map.put(entry.getKey(), entry.getValue().getParameterValue());
                }
            }
        }
        return map;
    }

    /**
     * 根据参数编码获取对象
     *
     * @param parameterCode
     * @return
     */
    public static ParameterVo getParameterVo(String parameterCode) {
        if (parameterCode != null && !"".equals(parameterCode)) {
            Map<String, ParameterVo> parameterVoMap = basicMap(Collections.singletonList(parameterCode));
            if (!parameterVoMap.isEmpty()) {
                return parameterVoMap.get(parameterCode);
            }
        }
        return null;
    }

    /**
     * 根据参数编码集合获取对象map
     *
     * @param parameterCodeList
     * @return
     */
    public static Map<String, ParameterVo> getParameterVoMap(List<String> parameterCodeList) {
        if (parameterCodeList != null && parameterCodeList.size() > 0) {
            return basicMap(parameterCodeList);
        }
        return new HashMap<>();
    }

    /**
     * 私有、统一逻辑、批量获取vo
     *
     * @param parameterCodeList
     * @return
     */
    private static Map<String, ParameterVo> basicMap(List<String> parameterCodeList) {
        Map<String, ParameterVo> map = new HashMap<>(16);
        try {
            if (parameterCodeList != null && parameterCodeList.size() > 0) {
                List<String> unlockCodeList = parameterCodeList.stream().filter(
                        parameterCode -> !checkLock(parameterCode)
                ).collect(Collectors.toList());
                List<String> notCacheCodeList = new ArrayList<>();
                for (String parameterCode :
                        unlockCodeList) {
                    Object o = redisService.get(RedisParam.PARAMETER + parameterCode);
                    if (o == null) {
                        notCacheCodeList.add(parameterCode);
                    } else {
                        map.put(parameterCode, (ParameterVo) o);
                    }
                }
                if (notCacheCodeList.size() > 0) {
                    Result<List<ParameterVo>> result = parameterFeign.getParameterRedisList(parameterCodeList);
                    if (result.isSuccess()) {
                        List<ParameterVo> list = result.getResult();
                        if (list != null && list.size() > 0) {
                            Map<String, ParameterVo> collect = list.stream().collect(Collectors.toMap(ParameterVo::getParameterCode, v -> v));
                            for (String parameterCode :
                                    notCacheCodeList) {
                                if (!collect.containsKey(parameterCode)) {
                                    lock(parameterCode);
                                } else {
                                    addRedisCache(collect.get(parameterCode));
                                    map.put(parameterCode, collect.get(parameterCode));
                                }
                            }
                        }
                    }
                }
            }
        } catch (Exception e) {
            log.error("全局参数工具类异常：{}", e);
        }
        return map;
    }

    /**
     * 批量远程获取
     *
     * @param parameterCodeList
     * @return
     */
    private static List<ParameterVo> getParameterVoList(List<String> parameterCodeList) {
        Result<List<ParameterVo>> result = parameterFeign.getParameterRedisList(parameterCodeList);
        if (result.isSuccess()) {
            List<ParameterVo> list = result.getResult();
            if (list != null && list.size() > 0) {
                return list;
            }
        }
        return new ArrayList<>();
    }

    /**
     * 删除缓存
     *
     * @param parameterCode
     */
    public static void deleteRedisCache(String parameterCode) {
        if (parameterCode != null && !"".equals(parameterCode)) {
            redisService.del(RedisParam.PARAMETER + parameterCode);
            redisService.del(RedisParam.PARAMETER_LOCK + parameterCode);
        }
    }

    /**
     * 添加缓存
     *
     * @param parameterVo
     */
    private static void addRedisCache(ParameterVo parameterVo) {
        if (parameterVo != null) {
            redisService.set(RedisParam.PARAMETER + parameterVo.getParameterCode(), parameterVo);
        }
    }

    /**
     * 加锁
     *
     * @param parameterCode
     */
    private static void lock(String parameterCode) {
        if (parameterCode != null && !"".equals(parameterCode)) {
            redisService.setSeconds(RedisParam.PARAMETER_LOCK + parameterCode, parameterCode, RedisParam.TIME5);
        }
    }

    /**
     * 检查是否被锁
     *
     * @param parameterCode
     * @return
     */
    private static boolean checkLock(String parameterCode) {
        if (parameterCode != null && !"".equals(parameterCode)) {
            return redisService.get(RedisParam.PARAMETER_LOCK + parameterCode) != null;
        }
        return false;
    }
}

==> crm-commom-1.2.8.1.release.jar: com/biz/crm/util/ParamUtil.java <==
package com.biz.crm.util;

import com.biz.crm.base.BusinessException;
import com.biz.crm.common.param.RedisParam;
import com.biz.crm.parameter.feign.ParameterFeign;
import com.biz.crm.parameter.vo.ParameterVo;
import com.biz.crm.service.RedisService;
import lombok.extern.slf4j.Slf4j;

import java.util.*;
import java.util.stream.Collectors;


/**
 * 全局参数工具类
 *
 * @author Tao.Chen
 * @date 2020-11-28 20:04:56
 */
@Slf4j
public class ParamUtil {

    private static ParameterFeign parameterFeign;
    private static RedisService redisService;

    public static void setParameterFeign(ParameterFeign feign) {
        parameterFeign = feign;
    }

    public static void setRedisService(RedisService redis) {
        redisService = redis;
    }

    /**
     * 根据参数编码获取当前值
     *
     * @param parameterCode
     * @return
     */
    public static String getParameterValue(String parameterCode) {
        if (parameterCode == null || "".equals(parameterCode)) {
            throw new BusinessException("请传入全局参数编码");
        }
        ParameterVo parameterVo = getParameterVo(parameterCode);
        if (parameterVo == null) {
            throw new BusinessException("未配置全局参数：" + parameterCode);
        }
        return parameterVo.getParameterValue();
    }

    /**
     * 根据参数编码集合获取当前值Map
     *
     * @param parameterCodeList
     * @return
     */
    public static Map<String, String> getParameterValueMap(List<String> parameterCodeList) {
        Map<String, String> map = new HashMap<>(16);
        if (parameterCodeList != null && parameterCodeList.size() > 0) {
            Map<String, ParameterVo> parameterVoMap = basicMap(parameterCodeList);
            if (!parameterVoMap.isEmpty()) {
                for (Map.Entry<String, ParameterVo> entry :
                        parameterVoMap.entrySet()) {
                    map.put(entry.getKey(), entry.getValue().getParameterValue());
                }
            }
        }
        return map;
    }

    /**
     * 根据参数编码获取对象
     *
     * @param parameterCode
     * @return
     */
    public static ParameterVo getParameterVo(String parameterCode) {
        if (parameterCode != null && !"".equals(parameterCode)) {
            Map<String, ParameterVo> parameterVoMap = basicMap(Collections.singletonList(parameterCode));
            if (!parameterVoMap.isEmpty()) {
                return parameterVoMap.get(parameterCode);
            }
        }
        return null;
    }

    /**
     * 根据参数编码集合获取对象map
     *
     * @param parameterCodeList
     * @return
     */
    public static Map<String, ParameterVo> getParameterVoMap(List<String> parameterCodeList) {
        if (parameterCodeList != null && parameterCodeList.size() > 0) {
            return basicMap(parameterCodeList);
        }
        return new HashMap<>();
    }

    /**
     * 私有、统一逻辑、批量获取vo
     *
     * @param parameterCodeList
     * @return
     */
    private static Map<String, ParameterVo> basicMap(List<String> parameterCodeList) {
        Map<String, ParameterVo> map = new HashMap<>(16);
        try {
            if (parameterCodeList != null && parameterCodeList.size() > 0) {
                List<String> unlockCodeList = parameterCodeList.stream().filter(
                        parameterCode -> !checkLock(parameterCode)
                ).collect(Collectors.toList());
                List<String> notCacheCodeList = new ArrayList<>();
                for (String parameterCode :
                        unlockCodeList) {
                    Object o = redisService.get(RedisParam.PARAMETER + parameterCode);
                    if (o == null) {
                        notCacheCodeList.add(parameterCode);
                    } else {
                        map.put(parameterCode, (ParameterVo) o);
                    }
                }
                if (notCacheCodeList.size() > 0) {
                    Result<List<ParameterVo>> result = parameterFeign.getParameterRedisList(parameterCodeList);
                    if (result.isSuccess()) {
                        List<ParameterVo> list = result.getResult();
                        if (list != null && list.size() > 0) {
                            Map<String, ParameterVo> collect = list.stream().collect(Collectors.toMap(ParameterVo::getParameterCode, v -> v));
                            for (String parameterCode :
                                    notCacheCodeList) {
                                if (!collect.containsKey(parameterCode)) {
                                    lock(parameterCode);
                                } else {
                                    addRedisCache(collect.get(parameterCode));
                                    map.put(parameterCode, collect.get(parameterCode));
                                }
                            }
                        }
                    }
                }
            }
        } catch (Exception e) {
            log.error("全局参数工具类异常：{}", e);
        }
        return map;
    }

    /**
     * 批量远程获取
     *
     * @param parameterCodeList
     * @return
     */
    private static List<ParameterVo> getParameterVoList(List<String> parameterCodeList) {
        Result<List<ParameterVo>> result = parameterFeign.getParameterRedisList(parameterCodeList);
        if (result.isSuccess()) {
            List<ParameterVo> list = result.getResult();
            if (list != null && list.size() > 0) {
                return list;
            }
        }
        return new ArrayList<>();
    }

    /**
     * 删除缓存
     *
     * @param parameterCode
     */
    public static void deleteRedisCache(String parameterCode) {
        if (parameterCode != null && !"".equals(parameterCode)) {
            redisService.del(RedisParam.PARAMETER + parameterCode);
            redisService.del(RedisParam.PARAMETER_LOCK + parameterCode);
        }
    }

    /**
     * 添加缓存
     *
     * @param parameterVo
     */
    private static void addRedisCache(ParameterVo parameterVo) {
        if (parameterVo != null) {
            redisService.set(RedisParam.PARAMETER + parameterVo.getParameterCode(), parameterVo);
        }
    }

    /**
     * 加锁
     *
     * @param parameterCode
     */
    private static void lock(String parameterCode) {
        if (parameterCode != null && !"".equals(parameterCode)) {
            redisService.setSeconds(RedisParam.PARAMETER_LOCK + parameterCode, parameterCode, RedisParam.TIME5);
        }
    }

    /**
     * 检查是否被锁
     *
     * @param parameterCode
     * @return
     */
    private static boolean checkLock(String parameterCode) {
        if (parameterCode != null && !"".equals(parameterCode)) {
            return redisService.get(RedisParam.PARAMETER_LOCK + parameterCode) != null;
        }
        return false;
    }
}
